output

package
v0.0.0-...-aef646c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 17, 2017 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

package output exists for stringer generation because having it in autofactory results in go stringer errors. This is probably a PEBKAC on my part but here it is.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Type

type Type int

OutputType is the type of destination the collected data is written to.

const (
	Unsupported Type = iota
	File
	InfluxDB
)

func TypeFromString

func TypeFromString(s string) Type

TypeFromString returns the Type for a given string. All input strings are normalized to lowercase; unmatched strings return Unsupported.

func (Type) String

func (i Type) String() string

Jump to