Documentation
¶
Overview ¶
package output exists for stringer generation because having it in autofactory results in go stringer errors. This is probably a PEBKAC on my part but here it is.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Type ¶
type Type int
OutputType is the type of destination the collected data is written to.
func TypeFromString ¶
TypeFromString returns the Type for a given string. All input strings are normalized to lowercase; unmatched strings return Unsupported.
Click to show internal directories.
Click to hide internal directories.